pitchtools.NumberedPitchClassObject
===================================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject

.. autoclass:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__repr__
   :noindex:
